==> rocoecup-order-api-1.0-20140424.065301-42-sources.jar: com/rocoinfo/rocoecup/order/entity/DeliverAddress.java <==
package com.rocoinfo.rocoecup.order.entity;

import com.rocoinfo.rocoecup.account.entity.User;
import com.rocoinfo.rocoecup.entity.IdEntity;

public class DeliverAddress extends IdEntity implements java.io.Serializable{
	/**
	 * 
	 */
	private static final long serialVersionUID = -5786826001274586575L;
	private String county;// 国家
	private String provice;// 省份
	private String city;// 城市
	private String street;// 街道
	private String postCode;// 邮编
	private String phone;// 收货人电话
	private String recipients;// 收货人姓名
	private User user;// 该地址属主

	public DeliverAddress() {
	}

	public DeliverAddress(Long id) {
		this.id = id;
	}

	public String getCounty() {
		return county;
	}

	public void setCounty(String county) {
		this.county = county;
	}

	public String getProvice() {
		return provice;
	}

	public void setProvice(String provice) {
		this.provice = provice;
	}

	public String getCity() {
		return city;
	}

	public void setCity(String city) {
		this.city = city;
	}

	public String getStreet() {
		return street;
	}

	public void setStreet(String street) {
		this.street = street;
	}

	public String getPostCode() {
		return postCode;
	}

	public void setPostCode(String postCode) {
		this.postCode = postCode;
	}

	public String getPhone() {
		return phone;
	}

	public void setPhone(String phone) {
		this.phone = phone;
	}

	public String getRecipients() {
		return recipients;
	}

	public void setRecipients(String recipients) {
		this.recipients = recipients;
	}

	public User getUser() {
		return user;
	}

	public void setUser(User user) {
		this.user = user;
	}

}

==> rocoecup-order-api-1.0-20140424.095452-52-sources.jar: com/rocoinfo/rocoecup/order/entity/DeliverAddress.java <==
package com.rocoinfo.rocoecup.order.entity;

import com.rocoinfo.rocoecup.entity.IdEntity;

public class DeliverAddress extends IdEntity implements java.io.Serializable {
	/**
	 * 
	 */
	private static final long serialVersionUID = -5786826001274586575L;
	private String county;// 国家
	private String provice;// 省份
	private String city;// 城市
	private String street;// 街道
	private String postCode;// 邮编
	private String phone;// 收货人电话
	private String recipients;// 收货人姓名
	private Long userId;// 该地址属主

	public DeliverAddress() {
	}

	public DeliverAddress(Long id) {
		this.id = id;
	}

	public String getCounty() {
		return county;
	}

	public void setCounty(String county) {
		this.county = county;
	}

	public String getProvice() {
		return provice;
	}

	public void setProvice(String provice) {
		this.provice = provice;
	}

	public String getCity() {
		return city;
	}

	public void setCity(String city) {
		this.city = city;
	}

	public String getStreet() {
		return street;
	}

	public void setStreet(String street) {
		this.street = street;
	}

	public String getPostCode() {
		return postCode;
	}

	public void setPostCode(String postCode) {
		this.postCode = postCode;
	}

	public String getPhone() {
		return phone;
	}

	public void setPhone(String phone) {
		this.phone = phone;
	}

	public String getRecipients() {
		return recipients;
	}

	public void setRecipients(String recipients) {
		this.recipients = recipients;
	}

	public Long getUserId() {
		return userId;
	}

	public void setUserId(Long userId) {
		this.userId = userId;
	}

}
